<?php

namespace Lavalite\Job\Providers;

use Illuminate\Support\ServiceProvider;

class JobServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'job');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'job');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('lavalite.job', function ($app) {
            return $this->app->make('Lavalite\Job\Job');
        });

        // Bind Tag to repository
        $this->app->bind(
            'Lavalite\Job\Interfaces\TagRepositoryInterface',
            \Lavalite\Job\Repositories\Eloquent\TagRepository::class
        );        // Bind Job to repository
        $this->app->bind(
            'Lavalite\Job\Interfaces\JobRepositoryInterface',
            \Lavalite\Job\Repositories\Eloquent\JobRepository::class
        );

        $this->app->register(\Lavalite\Job\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Lavalite\Job\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['lavalite.job'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('lavalite/job.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/job')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/job')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
